@@ -136,7 +136,7 @@ def insert(data: Iterable[dict] | pd.DataFrame, table: str, conn_kwargs: dict =
 def insert_ignore(
     data: Iterable[dict] | pd.DataFrame,
     table: str,
-    keys: list,
+    keys: Iterable,
     conn_kwargs: dict = None,
 ):
     """Function for SQL's INSERT ON CONFLICT DO NOTHING
@@ -248,6 +248,7 @@ def upsert(
     use_index: bool = True,
     conn_kwargs: dict = None,
 ):
+# TODO: should we have auto_index for auto create index & use_index for determing if index should be used?
     """Function for SQL's INSERT ON CONFLICT DO UPDATE SET
 
     Add a row into specified table if the row with specified keys does not already exist.
@@ -324,7 +325,7 @@ def upsert(
                 # TODO: Can i check if index exist rather than using error
                 except errors.InvalidColumnReference as e:
                     # print(">>> Error: ", e)
-                    # print(f"> Creating unique index for {keys}...")
+                    print(f"> Creating unique index for {keys}...")
                     # !Important, cannot attempt other operations after error unless rollback()
                     conn.rollback()
 
@@ -462,8 +463,8 @@ def update(
     """Function for SQL's UPDATE
 
     If rows with matching keys exist, update row values.
-    The columns that do not appear in the 'data' retain their original values.
-    Make sure data has keys specified in function.
+    The columns/info that is not provided in the 'data' retain their original values.
+    keys parameter must be specified in function.
 
     Args:
         data (list[dict] | pd.DataFrame): data in form of dict, list of dict, or dataframe
@@ -512,7 +513,7 @@ def update(
                     keys=keys,
                     exclude_update=exclude_update,
                 )
-                print(qry.as_string(conn))
+                # print(qry.as_string(conn))
                 cur.executemany(query=qry, params_seq=rows)
 
                 # Return # of updated records
@@ -529,7 +530,7 @@ def update(
                         exclude_update=exclude_update,
                     )
 
-                    print(qry.as_string(conn))
+                    # print(qry.as_string(conn))
                     cur.execute(query=qry, params=row)
                     rwcount += cur.rowcount
 
